import TopBar from '../../shared-components/TopBar';
import Summary from './components/Summary';
import Chart from './components/Chart';
import Table from './components/Table';
import Sidebar from './components/Sidebar';
import Footer from '../../shared-components/Footer';
import LoadingScreen from "../../shared-components/LoadingScreen";

const useState = wp.element.useState;
const useEffect = wp.element.useEffect;
import GridiconProductDownloadable from 'gridicons/dist/product-downloadable';
import GridiconReaderFollowConversation from 'gridicons/dist/reader-follow-conversation';
import GridiconInstitution from 'gridicons/dist/institution';

const App = () => {

    const [formData, setFormData] = useState(
        {
            dateRange: 0,
            converter: 0
        }
    );

    const [chartData, setChartData] = useState({});

    const [totalRequests, setTotalRequests] = useState(0);
    const [totalCharacters, setTotalCharacters] = useState(0);
    const [requestsPerDay, setRequestsPerDay] = useState(0);

    const [tableData, setTableData] = useState([]);

    const [dataAreLoaded, setDataAreLoaded] = useState(false);

    //Used to handle the changes to a React Select component
    function handleReactSelectChanges(e, name) {

        setFormData(prevFormData => {
            return {
                ...prevFormData,
                [name]: e.value,
            };
        });

    }

    useEffect(() => {

        /**
         * Initialize the chart data with the data received from the REST API
         * endpoint provided by the plugin.
         */
        wp.apiFetch({
            path: '/real-voice-pro/v1/requests',
            method: 'POST',
            data: {
                date_range: formData.dateRange,
                converter: formData.converter,
                nonce: window.DAEXTREVOP_PARAMETERS.read_requests_nonce
            }
        }).
        then(data => {

                    //create a new array with all the indexes of the "data" object
                    let labels = Object.keys(data.chart);
                    labels = labels.reverse();

                    //update the chart data
                    let values = Object.values(data.chart);
                    values = values.reverse();

                    //set the summary data
                    setTotalRequests(() => {
                        return data.summary.total_requests;
                    });
                    setTotalCharacters(() => {
                        return data.summary.total_characters;
                    });
                    setRequestsPerDay(() => {
                        return data.summary.requests_per_day;
                    });

                    //set the chart data
                    setChartData(() => {
                       return {
                           labels: labels,
                           dataset: values
                       };
                    });

                    //set the table data with setTableData()
                    setTableData(data.requests);

                    setDataAreLoaded(true);

            },
        );

    }, [
        formData
    ]);

  return (

      <>

          {
          dataAreLoaded ?

            <>

                <TopBar
                    GridiconProductDownloadable={GridiconProductDownloadable}
                    GridiconReaderFollowConversation={GridiconReaderFollowConversation}
                    GridiconInstitution={GridiconInstitution}
                />

                <div className={'daextrevop-content'}>

                    <div className="daextrevop-statistics-wrapper">

                        <div className="statistics-container">

                            <Summary
                                totalRequests={totalRequests}
                                totalCharacters={totalCharacters}
                                requestsPerDay={requestsPerDay}
                            />
                            <Chart
                                chartData={chartData}
                            />
                            <Table
                                data={tableData}
                            />

                        </div>

                        <Sidebar
                            formData={formData}
                            handleReactSelectChanges={handleReactSelectChanges}
                        />

                    </div>

                </div>

                <Footer/>

          </>

          :
          <LoadingScreen/>

      }

      </>
  );

};
export default App;