import {
  Chart as ChartJS,
  CategoryScale,
  LinearScale,
  PointElement,
  LineElement,
  Title,
  Tooltip,
  Legend,
} from 'chart.js';
import {Line} from 'react-chartjs-2';

ChartJS.register(
    CategoryScale,
    LinearScale,
    PointElement,
    LineElement,
    Title,
    Tooltip,
    Legend,
);

export const options = {
  responsive: true,
  maintainAspectRatio: false,
  plugins: {
    legend: {
      display: false,
      position: 'bottom',
    },
    title: {
      display: false
    },
  },
  scales: {
    x: {
      ticks: {
        autoSkip: true,
        maxTicksLimit: 6,
      },
      grid: {
        display: false,
      },
    },
    y: {
      border: {
        display: false,
      },
      min: 0,
      ticks: {
        autoSkip: true,
        maxTicksLimit: 5,
        callback: (value, index, values) => {
          return parseInt(value, 10);
        },
        stepSize: 1,
      },
      title: {
        display: false
      }
    }
  }
};

const LineChart = (props) => {

  const labels = props.chartData.labels;

  const data = {
    labels,
    datasets: [
      {
        label: 'Dataset 1',
        data: props.chartData.dataset,
        borderColor: 'rgb(141, 30, 119)',
        backgroundColor: 'rgba(141, 30, 119, 0.5)',
      }
    ],
  };

  return (

      <div>

        <Line options={options} data={data}/>

      </div>

  );

};

export default LineChart;
