<?php
/**
 * The Shared class is used to store properties and methods shared by the admin and public side of WordPress.
 *
 * @package real-voice-pro
 */

/**
 * This class should be used to stores properties and methods shared by the
 *  admin and public side of WordPress.
 */
class Daextrevop_Shared {

	/**
	 * The singleton instance of the class.
	 *
	 * @var Daextrevop_Shared
	 */
	protected static $instance = null;

	/**
	 * The data array.
	 *
	 * @var array
	 */
	private $data = array();

	/**
	 * Daextrevop_Shared constructor.
	 */
	private function __construct() {

		$this->data['slug'] = 'daextrevop';
		$this->data['ver']  = '1.24';
		$this->data['dir']  = substr( plugin_dir_path( __FILE__ ), 0, - 7 );
		$this->data['url']  = substr( plugin_dir_url( __FILE__ ), 0, - 7 );
		$this->data['plugin_upload_path'] = WP_CONTENT_DIR . '/uploads/daextrevop_uploads/';

		// Here are stored the plugin option with the related default values.
		$this->data['options'] = array(

			// Database Version ---------------------------------------------------------------------------------------.
			$this->get( 'slug' ) . '_database_version'     => '0',

			// Text-to-Speech ------------------------------------------------------------------------------------------.
			$this->get( 'slug' ) . '_text_to_speech_converter' => 'speechsyntesis-api',

			$this->get( 'slug' ) . '_speech_synthesis_lang' => '',
			$this->get( 'slug' ) . '_speech_synthesis_pitch' => '1',
			$this->get( 'slug' ) . '_speech_synthesis_rate' => '1',
			$this->get( 'slug' ) . '_speech_synthesis_volume' => '1',

			$this->get( 'slug' ) . '_elevenlabs_api_key'   => '',
			$this->get( 'slug' ) . '_elevenlabs_voice_id'  => '21m00Tcm4TlvDq8ikWAM',
			$this->get( 'slug' ) . '_elevenlabs_custom_voice_id'  => '',
			$this->get( 'slug' ) . '_elevenlabs_optimize_streaming_latency' => '0',
			$this->get( 'slug' ) . '_elevenlabs_stability' => '0',
			$this->get( 'slug' ) . '_elevenlabs_similarity_boost' => '0',
			$this->get( 'slug' ) . '_elevenlabs_style'     => '0',
			$this->get( 'slug' ) . '_elevenlabs_use_speaker_boost' => '1',
			$this->get( 'slug' ) . '_elevenlabs_model_id'  => 'eleven_multilingual_v2',

			$this->get( 'slug' ) . '_aws_access_key_id'    => '',
			$this->get( 'slug' ) . '_aws_secret_access_key' => '',
			$this->get( 'slug' ) . '_aws_region'           => 'us-east-1',
			$this->get( 'slug' ) . '_aws_voice_id'         => 'Joanna',
			$this->get( 'slug' ) . '_aws_engine'           => 'neural',
			$this->get( 'slug' ) . '_aws_language_code'    => 'en-US',
			$this->get( 'slug' ) . '_aws_lexicon_names'    => '',
			$this->get( 'slug' ) . '_aws_output_format'    => 'mp3',
			$this->get( 'slug' ) . '_aws_sample_rate'      => '',
			$this->get( 'slug' ) . '_google_cloud_text_to_speech_api_key' => '',
			$this->get( 'slug' ) . '_google_cloud_audio_config_audio_encoding' => 'LINEAR16',
			$this->get( 'slug' ) . '_google_cloud_audio_config_speaking_rate' => '1.0',
			$this->get( 'slug' ) . '_google_cloud_audio_config_pitch' => '0.0',
			$this->get( 'slug' ) . '_google_cloud_audio_config_volume_gain_db' => '0.0',
			$this->get( 'slug' ) . '_google_cloud_audio_config_sample_rate_hertz' => '0',
			$this->get( 'slug' ) . '_google_cloud_audio_config_effects_profile_id' => '',
			$this->get( 'slug' ) . '_google_cloud_voice_language_code' => 'en-US',
			$this->get( 'slug' ) . '_google_cloud_voice_name' => 'en-US-Wavenet-F',
			$this->get( 'slug' ) . '_azure_speech_resource_key' => '',
			$this->get( 'slug' ) . '_azure_region'         => 'eastus',
			$this->get( 'slug' ) . '_azure_user_agent'     => 'Default Agent',
			$this->get( 'slug' ) . '_azure_x_microsoft_output_format' => 'audio-24khz-160kbitrate-mono-mp3',
			$this->get( 'slug' ) . '_azure_voice_short_name' => 'en-US-ChristopherNeural',

			// Style --------------------------------------------------------------------------------------------------.
			$this->get( 'slug' ) . '_custom_player_background_color' => '#FFFFFF',
			$this->get( 'slug' ) . '_custom_player_border_color' => '#FFFFFF',
			$this->get( 'slug' ) . '_custom_player_icons_color' => '#5A5A5A',
			$this->get( 'slug' ) . '_custom_player_slider_thumb_color' => '#4285F4',
			$this->get( 'slug' ) . '_custom_player_slider_track_color' => '#DADADA',
			$this->get( 'slug' ) . '_custom_player_text_color' => '#333333',
			$this->get( 'slug' ) . '_custom_player_font_family' => "'Inter', sans-serif",
			$this->get( 'slug' ) . '_custom_player_font_size' => '14',
			$this->get( 'slug' ) . '_custom_player_font_style' => 'normal',
			$this->get( 'slug' ) . '_custom_player_font_weight' => '600',
			$this->get( 'slug' ) . '_custom_player_line_height' => '24',
			$this->get( 'slug' ) . '_custom_player_drop_shadow' => '1',
			$this->get( 'slug' ) . '_custom_player_drop_shadow_color' => '#101828',

			// General ------------------------------------------------------------------------------------------------.

			/**
			 * - 'speechsyntesis-api'
			 * - 'amazon-polly'
			 * - 'elevenlabs'
			 * - 'google-text-to-speech-ai'
			 * - 'azure-text-to-speech'
			 * - 'watson-text-to-speech'
			 */
			$this->get( 'slug' ) . '_post_types'           => array( 'post', 'page' ),
			$this->get( 'slug' ) . '_post_types_ui'        => array( 'post', 'page' ),
			$this->get( 'slug' ) . '_text_before'          => '',
			$this->get( 'slug' ) . '_text_after'           => '',
			$this->get( 'slug' ) . '_download_button'      => '0',
			$this->get( 'slug' ) . '_speech_text_before'   => '',
			$this->get( 'slug' ) . '_speech_text_after'    => '',
			$this->get( 'slug' ) . '_read_title'           => '0',

			// Advanced -----------------------------------------------------------------------------------------------.
			$this->get( 'slug' ) . '_generate_audio_on_post_view' => '0',
			$this->get( 'slug' ) . '_responsive_breakpoint' => '1024',
			$this->get( 'slug' ) . '_responsive_breakpoint_2' => '768',
			$this->get( 'slug' ) . '_google_font_url'      => 'https://fonts.googleapis.com/css2?family=Inter:wght@600&display=swap',
			$this->get( 'slug' ) . '_development_mode'     => '0',
			$this->get( 'slug' ) . '_statistics_menu_capability' => 'manage_options',
			$this->get( 'slug' ) . '_editor_tools_capability' => 'edit_posts',

		);
	}

	/**
	 * Get the singleton instance of the class.
	 *
	 * @return Daextrevop_Shared|self|null
	 */
	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Retrieve data.
	 *
	 * @param string $index The index of the data to retrieve.
	 *
	 * @return mixed
	 */
	public function get( $index ) {
		return $this->data[ $index ];
	}

	/**
	 * Register the support of the 'custom-fields' to all the post type with UI.
	 *
	 * The 'custom-fields' support is required by the sidebar components that use meta data. Without the
	 * 'custom-fields' support associated with the posts, the following meta data can't be used by the sidebar
	 * components and a JavaScript error breaks the editor:
	 *
	 * - _daextrevop_audio_file_url
	 * - _daextrevop_audio_file_creation_date
	 * - _daextrevop_text_to_speech
	 * - _daextrevop_document_type
	 *
	 * Note that the problem solved by this method occurs only when a post type is registered and the "supports" array
	 * doesn't include the 'custom-fields' value.
	 *
	 * See: https://developer.wordpress.org/reference/functions/add_post_type_support/
	 */
	public function register_support_on_post_types() {

		// Get the post types with UI.
		$available_post_types_a = get_post_types(
			array(
				'show_ui' => true,
			)
		);

		// Remove the 'attachment' post type.
		$available_post_types_a = array_diff( $available_post_types_a, array( 'attachment' ) );

		// Add the 'custom-fields' support to the post types with UI.
		foreach ( $available_post_types_a as $available_post_type ) {
			add_post_type_support( $available_post_type, 'custom-fields' );
		}
	}

}